@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,25 +16,30 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.dataflow_v1beta3.services.jobs_v1_beta3 import pagers
-from google.cloud.dataflow_v1beta3.types import environment
-from google.cloud.dataflow_v1beta3.types import jobs
-from google.cloud.dataflow_v1beta3.types import snapshots
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import JobsV1Beta3Transport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import JobsV1Beta3GrpcAsyncIOTransport
+
+from google.cloud.dataflow_v1beta3.services.jobs_v1_beta3 import pagers
+from google.cloud.dataflow_v1beta3.types import environment, jobs, snapshots
+
 from .client import JobsV1Beta3Client
+from .transports.base import DEFAULT_CLIENT_INFO, JobsV1Beta3Transport
+from .transports.grpc_asyncio import JobsV1Beta3GrpcAsyncIOTransport
 
 
 class JobsV1Beta3AsyncClient:
@@ -102,6 +107,42 @@ class JobsV1Beta3AsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return JobsV1Beta3Client.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> JobsV1Beta3Transport:
         """Returns the transport used by the client instance.
@@ -164,9 +205,9 @@ class JobsV1Beta3AsyncClient:
 
     async def create_job(
         self,
-        request: jobs.CreateJobRequest = None,
+        request: Union[jobs.CreateJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
@@ -178,8 +219,26 @@ class JobsV1Beta3AsyncClient:
         Using ``projects.jobs.create`` is not recommended, as your job
         will always start in ``us-central1``.
 
+        .. code-block:: python
+
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_create_job():
+                # Create a client
+                client = dataflow_v1beta3.JobsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.CreateJobRequest(
+                )
+
+                # Make the request
+                response = await client.create_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.CreateJobRequest`):
+            request (Union[google.cloud.dataflow_v1beta3.types.CreateJobRequest, dict]):
                 The request object. Request to create a Cloud Dataflow
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -191,7 +250,7 @@ class JobsV1Beta3AsyncClient:
         Returns:
             google.cloud.dataflow_v1beta3.types.Job:
                 Defines a job to be run by the Cloud
-                Dataflow service. nextID: 26
+                Dataflow service.
 
         """
         # Create or coerce a protobuf request object.
@@ -205,17 +264,33 @@ class JobsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def get_job(
         self,
-        request: jobs.GetJobRequest = None,
+        request: Union[jobs.GetJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
@@ -227,8 +302,26 @@ class JobsV1Beta3AsyncClient:
         Using ``projects.jobs.get`` is not recommended, as you can only
         get the state of jobs that are running in ``us-central1``.
 
+        .. code-block:: python
+
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_get_job():
+                # Create a client
+                client = dataflow_v1beta3.JobsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.GetJobRequest(
+                )
+
+                # Make the request
+                response = await client.get_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.GetJobRequest`):
+            request (Union[google.cloud.dataflow_v1beta3.types.GetJobRequest, dict]):
                 The request object. Request to get the state of a Cloud
                 Dataflow job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -240,7 +333,7 @@ class JobsV1Beta3AsyncClient:
         Returns:
             google.cloud.dataflow_v1beta3.types.Job:
                 Defines a job to be run by the Cloud
-                Dataflow service. nextID: 26
+                Dataflow service.
 
         """
         # Create or coerce a protobuf request object.
@@ -254,17 +347,34 @@ class JobsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def update_job(
         self,
-        request: jobs.UpdateJobRequest = None,
+        request: Union[jobs.UpdateJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
@@ -277,8 +387,26 @@ class JobsV1Beta3AsyncClient:
         only update the state of jobs that are running in
         ``us-central1``.
 
+        .. code-block:: python
+
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_update_job():
+                # Create a client
+                client = dataflow_v1beta3.JobsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.UpdateJobRequest(
+                )
+
+                # Make the request
+                response = await client.update_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.UpdateJobRequest`):
+            request (Union[google.cloud.dataflow_v1beta3.types.UpdateJobRequest, dict]):
                 The request object. Request to update a Cloud Dataflow
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -290,7 +418,7 @@ class JobsV1Beta3AsyncClient:
         Returns:
             google.cloud.dataflow_v1beta3.types.Job:
                 Defines a job to be run by the Cloud
-                Dataflow service. nextID: 26
+                Dataflow service.
 
         """
         # Create or coerce a protobuf request object.
@@ -304,17 +432,34 @@ class JobsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_jobs(
         self,
-        request: jobs.ListJobsRequest = None,
+        request: Union[jobs.ListJobsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobsAsyncPager:
@@ -328,8 +473,27 @@ class JobsV1Beta3AsyncClient:
         not recommended, as you can only get the list of jobs that are
         running in ``us-central1``.
 
+        .. code-block:: python
+
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_list_jobs():
+                # Create a client
+                client = dataflow_v1beta3.JobsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.ListJobsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_jobs(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.ListJobsRequest`):
+            request (Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]):
                 The request object. Request to list Cloud Dataflow jobs.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -364,13 +528,32 @@ class JobsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListJobsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -378,16 +561,35 @@ class JobsV1Beta3AsyncClient:
 
     async def aggregated_list_jobs(
         self,
-        request: jobs.ListJobsRequest = None,
+        request: Union[jobs.ListJobsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListJobsAsyncPager:
         r"""List the jobs of a project across all regions.
 
+        .. code-block:: python
+
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_aggregated_list_jobs():
+                # Create a client
+                client = dataflow_v1beta3.JobsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.ListJobsRequest(
+                )
+
+                # Make the request
+                page_result = client.aggregated_list_jobs(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.ListJobsRequest`):
+            request (Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]):
                 The request object. Request to list Cloud Dataflow jobs.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -422,13 +624,29 @@ class JobsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("project_id", request.project_id),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.AggregatedListJobsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -436,17 +654,35 @@ class JobsV1Beta3AsyncClient:
 
     async def check_active_jobs(
         self,
-        request: jobs.CheckActiveJobsRequest = None,
+        request: Union[jobs.CheckActiveJobsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.CheckActiveJobsResponse:
         r"""Check for existence of active jobs in the given
         project across all regions.
 
+        .. code-block:: python
+
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_check_active_jobs():
+                # Create a client
+                client = dataflow_v1beta3.JobsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.CheckActiveJobsRequest(
+                )
+
+                # Make the request
+                response = await client.check_active_jobs(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.CheckActiveJobsRequest`):
+            request (Union[google.cloud.dataflow_v1beta3.types.CheckActiveJobsRequest, dict]):
                 The request object. Request to check is active jobs
                 exists for a project
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -471,23 +707,46 @@ class JobsV1Beta3AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def snapshot_job(
         self,
-        request: jobs.SnapshotJobRequest = None,
+        request: Union[jobs.SnapshotJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> snapshots.Snapshot:
         r"""Snapshot the state of a streaming job.
 
+        .. code-block:: python
+
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_snapshot_job():
+                # Create a client
+                client = dataflow_v1beta3.JobsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.SnapshotJobRequest(
+                )
+
+                # Make the request
+                response = await client.snapshot_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.SnapshotJobRequest`):
+            request (Union[google.cloud.dataflow_v1beta3.types.SnapshotJobRequest, dict]):
                 The request object. Request to create a snapshot of a
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -511,8 +770,25 @@ class JobsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
