@@ -16,31 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.dataflow_v1beta3.services.jobs_v1_beta3 import pagers
-from google.cloud.dataflow_v1beta3.types import environment
-from google.cloud.dataflow_v1beta3.types import jobs
-from google.cloud.dataflow_v1beta3.types import snapshots
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import JobsV1Beta3Transport, DEFAULT_CLIENT_INFO
+
+from google.cloud.dataflow_v1beta3.services.jobs_v1_beta3 import pagers
+from google.cloud.dataflow_v1beta3.types import environment, jobs, snapshots
+
+from .transports.base import DEFAULT_CLIENT_INFO, JobsV1Beta3Transport
 from .transports.grpc import JobsV1Beta3GrpcTransport
 from .transports.grpc_asyncio import JobsV1Beta3GrpcAsyncIOTransport
 
@@ -57,7 +57,10 @@ class JobsV1Beta3ClientMeta(type):
     _transport_registry["grpc"] = JobsV1Beta3GrpcTransport
     _transport_registry["grpc_asyncio"] = JobsV1Beta3GrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[JobsV1Beta3Transport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[JobsV1Beta3Transport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -165,7 +168,9 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -178,9 +183,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -189,9 +198,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -200,9 +213,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -211,10 +228,14 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -386,6 +407,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_job(
@@ -404,7 +426,6 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         Using ``projects.jobs.create`` is not recommended, as your job
         will always start in ``us-central1``.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -451,8 +472,24 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.create_job]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -473,7 +510,6 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         Using ``projects.jobs.get`` is not recommended, as you can only
         get the state of jobs that are running in ``us-central1``.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -520,8 +556,25 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_job]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -543,7 +596,6 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         only update the state of jobs that are running in
         ``us-central1``.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -590,8 +642,25 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update_job]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -614,7 +683,6 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         not recommended, as you can only get the list of jobs that are
         running in ``us-central1``.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -671,13 +739,32 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list_jobs]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListJobsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -749,13 +836,29 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list_jobs]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("project_id", request.project_id),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.AggregatedListJobsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -772,7 +875,6 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         r"""Check for existence of active jobs in the given
         project across all regions.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -818,7 +920,12 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.check_active_jobs]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -877,8 +984,25 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.snapshot_job]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
